/* VERSION determines the program's version number
 * This file is part of jdupes; see jdupes.c for license information */

#ifndef JDUPES_VERSION_H
#define JDUPES_VERSION_H

#define VER "1.12"
#define VERDATE "2019-02-18"

#endif /* JDUPES_VERSION_H */
